chinese_patient = 'CP';
american_patient = 'UP';

%pattern for ECG
ecg_filename_pattern = '-%02d-ECG.mat';

%pattern for SCG
scg_filename_pattern = '-%02d-SCG.mat';

%pattern for GCG
gcg_filename_pattern = '-%02d-GCG.mat';

cp_file_pattern = strcat(chinese_patient, gcg_filename_pattern);
up_file_pattern = strcat(american_patient, gcg_filename_pattern);
pattern = up_file_pattern;

%number_of_files = length('CP-*-ECG.mat');
processed_files = dir('UP-*-GCG.mat');
number_of_files = length(processed_files);

%% Perform batch HRV analysis
results_matrix = cell(number_of_files, 13);

for i = 1:number_of_files
    
    filename = sprintf(pattern, i);
    load(filename);
    
    %ECG and GCG
    lead_index=2;
    %SKG
    %lead_index=3;
    
    nn = data.RR_int{1,lead_index}/1000;
    nn = [0 nn];
    tnn = seconds(data.R_loc{1,lead_index});
    out = calculate_hrv_indices(nn, tnn);
    
    subject_id = sprintf('subject_%d', i);
    hrv_indices_row = {subject_id, out.NNmean out.SDNN out.RMSSD ...
        out.pnn50 out.vlf, out.lf, out.hf, out.lfhf, out.SD1, out.SD2, out.SD1SD2, out.EA};
    
    results_matrix(i, :) = hrv_indices_row;
end

variable_names = {'Subject', 'AVNN', 'SDNN', ...
'RMSSD', 'pNN50', 'vlf', 'lf', 'hf', 'lfhf', 'SD1', 'SD2', 'SD1/SD2', 'EA'};
hrv_analysis_results = cell2table(results_matrix, 'VariableNames', variable_names);

writetable(hrv_analysis_results, 'HRV_indices.csv');
